==> orchestra-api-4.1.0-sources.jar: org/ow2/orchestra/facade/def/impl/OnEventDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import java.util.List;

import javax.xml.namespace.QName;

import org.ow2.orchestra.facade.def.CorrelationDefinition;
import org.ow2.orchestra.facade.def.FromPartDefinition;
import org.ow2.orchestra.facade.def.OnEventDefinition;
import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

public class OnEventDefinitionImpl implements OnEventDefinition {

  private String variable;

  private QName portType;

  private String partnerLink;

  private String operation;

  private String messageExchange;

  private List<FromPartDefinition> fromPartList;

  private List<CorrelationDefinition> correlationList;

  private ActivityDefinitionUUID activityDefinitionUUID;

  public OnEventDefinitionImpl(final OnEventDefinition onEventDefinition) {
    this.correlationList = onEventDefinition.getCorrelationDefinitionList();
    this.fromPartList = onEventDefinition.getFromPartDefinitionList();
    this.messageExchange = onEventDefinition.getMessageExchange();
    this.operation = onEventDefinition.getOperation();
    this.partnerLink = onEventDefinition.getPartnerLink();
    this.portType = onEventDefinition.getPortType();
    this.variable = onEventDefinition.getVariable();
    this.activityDefinitionUUID = onEventDefinition.getActivityDefinitionUUID();
  }

  public List<CorrelationDefinition> getCorrelationDefinitionList() {
    return this.correlationList;
  }

  public List<FromPartDefinition> getFromPartDefinitionList() {
    return this.fromPartList;
  }

  public String getMessageExchange() {
    return this.messageExchange;
  }

  public String getOperation() {
    return this.operation;
  }

  public String getPartnerLink() {
    return this.partnerLink;
  }

  public QName getPortType() {
    return this.portType;
  }

  public String getVariable() {
    return this.variable;
  }

  public OnEventDefinition copy() {
    return new OnEventDefinitionImpl(this);
  }

  public ActivityDefinitionUUID getActivityDefinitionUUID() {
    return this.activityDefinitionUUID;
  }

}

==> orchestra-api-4.2.1-sources.jar: org/ow2/orchestra/facade/def/impl/OnEventDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import java.util.List;

import javax.xml.namespace.QName;

import org.ow2.orchestra.facade.CopyUtil;
import org.ow2.orchestra.facade.def.CorrelationDefinition;
import org.ow2.orchestra.facade.def.FromPartDefinition;
import org.ow2.orchestra.facade.def.OnEventDefinition;
import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

public class OnEventDefinitionImpl implements OnEventDefinition {

  private final String variable;

  private final QName portType;

  private final String partnerLink;

  private final String operation;

  private final String messageExchange;

  private final List<FromPartDefinition> fromPartList;

  private final List<CorrelationDefinition> correlationList;

  private final ActivityDefinitionUUID activityDefinitionUUID;

  public OnEventDefinitionImpl(final OnEventDefinition onEventDefinition) {
    this.correlationList = CopyUtil.copyList(onEventDefinition.getCorrelationDefinitionList());
    this.fromPartList = CopyUtil.copyList(onEventDefinition.getFromPartDefinitionList());
    this.messageExchange = onEventDefinition.getMessageExchange();
    this.operation = onEventDefinition.getOperation();
    this.partnerLink = onEventDefinition.getPartnerLink();
    this.portType = onEventDefinition.getPortType();
    this.variable = onEventDefinition.getVariable();
    this.activityDefinitionUUID = onEventDefinition.getActivityDefinitionUUID();
  }

  public List<CorrelationDefinition> getCorrelationDefinitionList() {
    return this.correlationList;
  }

  public List<FromPartDefinition> getFromPartDefinitionList() {
    return this.fromPartList;
  }

  public String getMessageExchange() {
    return this.messageExchange;
  }

  public String getOperation() {
    return this.operation;
  }

  public String getPartnerLink() {
    return this.partnerLink;
  }

  public QName getPortType() {
    return this.portType;
  }

  public String getVariable() {
    return this.variable;
  }

  public OnEventDefinition copy() {
    return new OnEventDefinitionImpl(this);
  }

  public ActivityDefinitionUUID getActivityDefinitionUUID() {
    return this.activityDefinitionUUID;
  }

}
